@@ -1,15 +1,17 @@
 package v1
 
 import (
-	"k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset/scheme"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
-	k8sscheme "k8s.io/client-go/kubernetes/scheme"
+
+	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators"
 )
 
 const (
-	GroupName    = "operators.coreos.com"
+	// GroupName is the group name used in this package.
+	GroupName = operators.GroupName
+	// GroupVersion is the group version used in this package.
 	GroupVersion = "v1"
 )
 
@@ -27,17 +29,16 @@ func Resource(resource string) schema.GroupResource {
 }
 
 var (
+	// SchemeBuilder initializes a scheme builder
 	SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes)
-	AddToScheme   = SchemeBuilder.AddToScheme
-	serScheme     = runtime.NewScheme()
+	// AddToScheme is a global function that registers this API group & version to a scheme
+	AddToScheme = SchemeBuilder.AddToScheme
+
+	// localSchemeBuilder is expected by generated conversion functions
+	localSchemeBuilder = &SchemeBuilder
 )
 
-func init() {
-	k8sscheme.AddToScheme(serScheme)
-	scheme.AddToScheme(serScheme)
-}
-
-// Adds the list of known types to Scheme.
+// addKnownTypes adds the list of known types to Scheme
 func addKnownTypes(scheme *runtime.Scheme) error {
 	scheme.AddKnownTypes(SchemeGroupVersion,
 		&OperatorGroup{},
