@@ -34,7 +34,7 @@ import (
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/client/informers/externalversions"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/certs"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/install"
-	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/operators/olm/envvar"
+	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/operators/olm/overrides"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry/resolver"
 	csvutility "github.com/operator-framework/operator-lifecycle-manager/pkg/lib/csv"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/event"
@@ -476,9 +476,9 @@ func newOperatorWithConfig(ctx context.Context, config *operatorConfig) (*Operat
 		op.RegisterQueueInformer(informer)
 	}
 
-	proxyEnvInjector := envvar.NewDeploymentInitializer(op.logger, proxyQuerierInUse, op.lister)
+	overridesBuilderFunc := overrides.NewDeploymentInitializer(op.logger, proxyQuerierInUse, op.lister)
 	op.resolver = &install.StrategyResolver{
-		ProxyInjectorBuilderFunc: proxyEnvInjector.GetDeploymentInitializer,
+		OverridesBuilderFunc: overridesBuilderFunc.GetDeploymentInitializer,
 	}
 
 	return op, nil
@@ -906,11 +906,6 @@ func (a *Operator) removeDanglingChildCSVs(csv *v1alpha1.ClusterServiceVersion)
 		}
 	}
 
-	if parent.GetNamespace() == csv.GetNamespace() {
-		logger.Debug("deleting copied CSV since it has incorrect parent annotations")
-		return a.deleteChild(csv, logger)
-	}
-
 	return nil
 }
 
@@ -967,6 +962,8 @@ func (a *Operator) syncClusterServiceVersion(obj interface{}) (syncError error)
 			} else {
 				syncError = fmt.Errorf("error transitioning ClusterServiceVersion: %s and error updating CSV status: %s", syncError, updateErr)
 			}
+		} else {
+			metrics.EmitCSVMetric(clusterServiceVersion, outCSV)
 		}
 	}
 
@@ -1255,6 +1252,12 @@ func (a *Operator) transitionCSVState(in v1alpha1.ClusterServiceVersion) (out *v
 		if unionedAnnotations == nil {
 			unionedAnnotations = make(map[string]string)
 		}
+		if unionedAnnotations[v1.OperatorGroupProvidedAPIsAnnotationKey] == union.String() {
+			// resolver may think apis need adding with invalid input, so continue when there's no work
+			// to be done so that the CSV can progress far enough to get requirements checked
+			a.logger.Debug("operator group annotations up to date, continuing")
+			break
+		}
 		unionedAnnotations[v1.OperatorGroupProvidedAPIsAnnotationKey] = union.String()
 		operatorGroup.SetAnnotations(unionedAnnotations)
 		if _, err := a.client.OperatorsV1().OperatorGroups(operatorGroup.GetNamespace()).Update(operatorGroup); err != nil && !k8serrors.IsNotFound(err) {
